# PKR

[![Build Status](https://travis-ci.org/altairengineering/pkr.svg?branch=master)](https://travis-ci.org/altairengineering/pkr)

# Introduction
This repository provide a `structured templating` tool, with primary usage to build and deploy container images.

With a modular driver and extensions design, it can be used either only for templating or with docker, docker compose or k8s.

`pkr` comes from `pocker`, which was the first name of this software.

# Documentation

[Installation](doc/installation.md)

[Quickstart](doc/quickstart.md)

[Examples](doc/examples.md)

[Drivers](doc/drivers.md)

[Reference](doc/reference.md)
